=====
NABQR
=====


.. image:: https://img.shields.io/pypi/v/nabqr.svg
        :target: https://pypi.python.org/pypi/nabqr

.. image:: https://img.shields.io/travis/bast0320/nabqr.svg
        :target: https://travis-ci.com/bast0320/nabqr

.. image:: https://readthedocs.org/projects/nabqr/badge/?version=latest
        :target: https://nabqr.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status




NABQR is a method for sequential error-corrections tailored for wind power forecast in Denmark


* Free software: MIT license
* Documentation: https://nabqr.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
